function [s, ind] = grep(s, target, varargin)
% GREP(STRS, TARGET) 
% 	where STRS may be a string matrix or a cell array of string,
% 	and TARGET is a string, returns the lines of STRS that
% 	contain TARGET.
% 
% GREP(STRS, TARGET, FLAGS....)
% 	Flags are each single characters, preceded by an optional '-'.
% 	They may be run together in one string or supplied as separate
% 	arguments.
% 
% 	The 'i' character specifies a case insensitive match.
% 	The 's' character specifies a case sensitive match (this is the
% 	default mode).
% 	The 'n' character specifies a negative search: only strings
% 	which do not contain the TARGET are returned.
% 
% Apologies to users of the real grep, to which this function bears
% very little resemblance: I gave it the name "grep" simply to
% remind me what the function does (the names FINDSTR and STRMATCH
% are already taken, and the function does approximate the following:)
% 	echo $STRS | grep $TARGET

% Part of PFCMP version 2.5.41, an extension to the PSIGNIFIT toolbox for MATLAB versions 5 and up.
% The license and NO WARRANTY statement for PSIGNIFIT also applies to this release - see psych_legal.m
% Copyright (c) J.Hill 2002.
% mailto:psignifit@bootstrap-software.org
% http://www.bootstrap-software.org/psignifit/

if isempty(target), return, end

cellfmt = iscell(s);
s = cellstr(s); so = s; 

insens = 0;
neg = 0;

flags = char([varargin{:}]);
flags(findstr(flags, '-')) = [];
for i = 1:length(flags)
	switch flags(i)
		case 's', insens = 0;
		case 'i', insens = 1;
		case 'n', neg = 1;
		otherwise, error(sprintf('unknown command option -%s', flags(i)))
	end
end

if insens, target = lower(target); s = lower(s); end
s = s(:);
for i = 1:length(s)
	keep(i) = (min(findstr(target, [s{i} target char(0)])) <= length(s{i}));
end
if neg, keep = ~keep; end
s = so(keep);
ind = find(keep);
if ~cellfmt, s = char(s); end
