function [strOut, n, err] = jmatchstr(str, strs, varargin)
% [MATCHED, INDEX, ERR] = JMATCHSTR(STR, STRS [, FLAGS...])
% 
% Match string STR to cell array of strings STRS, returning the
% first match found
% Optional flags may include the following, which may be abbreviated
% 	'exact' - do not allow STR to be abbreviated
% 	'autocomplete' - allow STR to be abbreviated (default)
% 	'sensitive' - match case
% 	'insensitive' - do not match case (default)
% 
% If no match:
% 	error ERR is issued unless "caught" in the third output argument
% 	MATCHED returns the empty string
% 	INDEX returns 0

% Part of PFCMP version 2.5.41, an extension to the PSIGNIFIT toolbox for MATLAB versions 5 and up.
% The license and NO WARRANTY statement for PSIGNIFIT also applies to this release - see psych_legal.m
% Copyright (c) J.Hill 2002.
% mailto:psignifit@bootstrap-software.org
% http://www.bootstrap-software.org/psignifit/

if ~iscellstr(strs), error('STRS must be a cell array of strings'), end
if ~iscellstr(varargin), error('additional arguments must be strings'), end

strOut = ''; n = 0; err = '';
if ~isstr(str)
	err = 'must be a string';
	if nargout < 3, error(err), end
	return
end

str = str(:)';
strs = char(strs(:));
mFlag = {};

matchTo = lower(str);
chooseFrom = lower(strs);

for i = 1:length(varargin)
	flag = lower(varargin{i}); flag = flag(:)';
	if ~isempty(flag)
		if ~isempty(strmatch(flag, {'exact'})), mFlag = {'exact'};
		elseif ~isempty(strmatch(flag, {'autocomplete'})), mFlag = {};
		elseif ~isempty(strmatch(flag, {'sensitive'})), matchTo = str; chooseFrom = strs;
		elseif ~isempty(strmatch(flag, {'insensitive'})), matchTo = lower(str); chooseFrom = lower(strs);
		else error(sprintf('unknown command option ''%s'' to JMATCHSTRING', flag))
		end
	end
end

n = min(strmatch(matchTo, cellstr(chooseFrom), mFlag{:}));
if isempty(n)
	n = 0;
	strs = [repmat(sprintf('\t'), size(strs, 1), 1) strs repmat(sprintf('\n'), size(strs, 1), 1)]';
	strs = strs(1:end-1)';
	err = sprintf('unrecognized option ''%s'' - recognized values are\n%s', str, strs);
else
	strs = cellstr(strs);
	strOut = strs{n};
end

if nargout < 3, error(err), end
